@@ -13,6 +13,7 @@
 #include <QNetworkReply>
 #include <QStandardPaths>
 #include <QTextDocumentFragment>
+#include <Syndication/Syndication>
 
 #include "database.h"
 #include "fetcher.h"
@@ -54,10 +55,11 @@ void Fetcher::fetch(const QString &url, const bool markEntriesRead)
 void Fetcher::fetchAll()
 {
     QSqlQuery query;
-    query.prepare(QStringLiteral("SELECT url FROM Feeds;"));
-    Database::instance().execute(query);
-    while (query.next()) {
-        fetch(query.value(0).toString());
+    if (query.prepare(QStringLiteral("SELECT url FROM Feeds;"))) {
+        Database::instance().execute(query);
+        while (query.next()) {
+            fetch(query.value(0).toString());
+        }
     }
 }
 
@@ -77,32 +79,34 @@ void Fetcher::processFeed(Syndication::FeedPtr feed, const QString &url, const b
     }
 
     QSqlQuery query;
-    query.prepare(QStringLiteral("UPDATE Feeds SET name=:name, image=:image, link=:link, description=:description, lastUpdated=:lastUpdated WHERE url=:url;"));
-    query.bindValue(QStringLiteral(":name"), feed->title());
-    query.bindValue(QStringLiteral(":url"), url);
-    query.bindValue(QStringLiteral(":link"), feed->link());
-    query.bindValue(QStringLiteral(":description"), feed->description());
+    if (query.prepare(
+            QStringLiteral("UPDATE Feeds SET name=:name, image=:image, link=:link, description=:description, lastUpdated=:lastUpdated WHERE url=:url;"))) {
+        query.bindValue(QStringLiteral(":name"), feed->title());
+        query.bindValue(QStringLiteral(":url"), url);
+        query.bindValue(QStringLiteral(":link"), feed->link());
+        query.bindValue(QStringLiteral(":description"), feed->description());
 
-    QDateTime current = QDateTime::currentDateTime();
-    query.bindValue(QStringLiteral(":lastUpdated"), current.toSecsSinceEpoch());
+        QDateTime current = QDateTime::currentDateTime();
+        query.bindValue(QStringLiteral(":lastUpdated"), current.toSecsSinceEpoch());
 
-    for (auto &author : feed->authors()) {
-        processAuthor(author, QLatin1String(""), url);
+        for (auto &author : feed->authors()) {
+            processAuthor(author, QLatin1String(""), url);
+        }
+
+        QString imagePath;
+        if (feed->image()->url().startsWith(QStringLiteral("/"))) {
+            imagePath = QUrl(url).adjusted(QUrl::RemovePath).toString() + feed->image()->url();
+        } else {
+            imagePath = feed->image()->url();
+        }
+        query.bindValue(QStringLiteral(":image"), imagePath);
+        Database::instance().execute(query);
+
+        qDebug() << "Updated feed title:" << feed->title();
+
+        Q_EMIT feedDetailsUpdated(url, feed->title(), imagePath, feed->link(), feed->description(), current);
     }
 
-    QString image;
-    if (feed->image()->url().startsWith(QStringLiteral("/"))) {
-        image = QUrl(url).adjusted(QUrl::RemovePath).toString() + feed->image()->url();
-    } else {
-        image = feed->image()->url();
-    }
-    query.bindValue(QStringLiteral(":image"), image);
-    Database::instance().execute(query);
-
-    qDebug() << "Updated feed title:" << feed->title();
-
-    Q_EMIT feedDetailsUpdated(url, feed->title(), image, feed->link(), feed->description(), current);
-
     for (const auto &entry : feed->items()) {
         processEntry(entry, url, markEntriesRead);
     }
@@ -114,32 +118,34 @@ void Fetcher::processEntry(Syndication::ItemPtr entry, const QString &url, const
 {
     qDebug() << "Processing" << entry->title();
     QSqlQuery query;
-    query.prepare(QStringLiteral("SELECT COUNT (id) FROM Entries WHERE id=:id;"));
-    query.bindValue(QStringLiteral(":id"), entry->id());
-    Database::instance().execute(query);
-    query.next();
+    if (query.prepare(QStringLiteral("SELECT COUNT (id) FROM Entries WHERE id=:id;"))) {
+        query.bindValue(QStringLiteral(":id"), entry->id());
+        Database::instance().execute(query);
+        query.next();
 
-    if (query.value(0).toInt() != 0) {
-        return;
+        if (query.value(0).toInt() != 0) {
+            return;
+        }
     }
 
-    query.prepare(QStringLiteral("INSERT INTO Entries VALUES (:feed, :id, :title, :content, :created, :updated, :link, :read);"));
-    query.bindValue(QStringLiteral(":feed"), url);
-    query.bindValue(QStringLiteral(":id"), entry->id());
-    query.bindValue(QStringLiteral(":title"), QTextDocumentFragment::fromHtml(entry->title()).toPlainText());
-    query.bindValue(QStringLiteral(":created"), static_cast<int>(entry->datePublished()));
-    query.bindValue(QStringLiteral(":updated"), static_cast<int>(entry->dateUpdated()));
-    query.bindValue(QStringLiteral(":link"), entry->link());
-    query.bindValue(QStringLiteral(":read"), markEntriesRead);
+    if (query.prepare(QStringLiteral("INSERT INTO Entries VALUES (:feed, :id, :title, :content, :created, :updated, :link, :read);"))) {
+        query.bindValue(QStringLiteral(":feed"), url);
+        query.bindValue(QStringLiteral(":id"), entry->id());
+        query.bindValue(QStringLiteral(":title"), QTextDocumentFragment::fromHtml(entry->title()).toPlainText());
+        query.bindValue(QStringLiteral(":created"), static_cast<int>(entry->datePublished()));
+        query.bindValue(QStringLiteral(":updated"), static_cast<int>(entry->dateUpdated()));
+        query.bindValue(QStringLiteral(":link"), entry->link());
+        query.bindValue(QStringLiteral(":read"), markEntriesRead);
 
-    if (!entry->content().isEmpty()) {
-        query.bindValue(QStringLiteral(":content"), entry->content());
-    } else {
-        query.bindValue(QStringLiteral(":content"), entry->description());
+        if (!entry->content().isEmpty()) {
+            query.bindValue(QStringLiteral(":content"), entry->content());
+        } else {
+            query.bindValue(QStringLiteral(":content"), entry->description());
+        }
+
+        Database::instance().execute(query);
     }
 
-    Database::instance().execute(query);
-
     for (const auto &author : entry->authors()) {
         processAuthor(author, entry->id(), url);
     }
@@ -152,27 +158,29 @@ void Fetcher::processEntry(Syndication::ItemPtr entry, const QString &url, const
 void Fetcher::processAuthor(Syndication::PersonPtr author, const QString &entryId, const QString &url)
 {
     QSqlQuery query;
-    query.prepare(QStringLiteral("INSERT INTO Authors VALUES(:feed, :id, :name, :uri, :email);"));
-    query.bindValue(QStringLiteral(":feed"), url);
-    query.bindValue(QStringLiteral(":id"), entryId);
-    query.bindValue(QStringLiteral(":name"), author->name());
-    query.bindValue(QStringLiteral(":uri"), author->uri());
-    query.bindValue(QStringLiteral(":email"), author->email());
-    Database::instance().execute(query);
+    if (query.prepare(QStringLiteral("INSERT INTO Authors VALUES(:feed, :id, :name, :uri, :email);"))) {
+        query.bindValue(QStringLiteral(":feed"), url);
+        query.bindValue(QStringLiteral(":id"), entryId);
+        query.bindValue(QStringLiteral(":name"), author->name());
+        query.bindValue(QStringLiteral(":uri"), author->uri());
+        query.bindValue(QStringLiteral(":email"), author->email());
+        Database::instance().execute(query);
+    }
 }
 
 void Fetcher::processEnclosure(Syndication::EnclosurePtr enclosure, Syndication::ItemPtr entry, const QString &feedUrl)
 {
     QSqlQuery query;
-    query.prepare(QStringLiteral("INSERT INTO Enclosures VALUES (:feed, :id, :duration, :size, :title, :type, :url);"));
-    query.bindValue(QStringLiteral(":feed"), feedUrl);
-    query.bindValue(QStringLiteral(":id"), entry->id());
-    query.bindValue(QStringLiteral(":duration"), enclosure->duration());
-    query.bindValue(QStringLiteral(":size"), enclosure->length());
-    query.bindValue(QStringLiteral(":title"), enclosure->title());
-    query.bindValue(QStringLiteral(":type"), enclosure->type());
-    query.bindValue(QStringLiteral(":url"), enclosure->url());
-    Database::instance().execute(query);
+    if (query.prepare(QStringLiteral("INSERT INTO Enclosures VALUES (:feed, :id, :duration, :size, :title, :type, :url);"))) {
+        query.bindValue(QStringLiteral(":feed"), feedUrl);
+        query.bindValue(QStringLiteral(":id"), entry->id());
+        query.bindValue(QStringLiteral(":duration"), enclosure->duration());
+        query.bindValue(QStringLiteral(":size"), enclosure->length());
+        query.bindValue(QStringLiteral(":title"), enclosure->title());
+        query.bindValue(QStringLiteral(":type"), enclosure->type());
+        query.bindValue(QStringLiteral(":url"), enclosure->url());
+        Database::instance().execute(query);
+    }
 }
 
 QString Fetcher::image(const QString &url)
